@@ -42,7 +42,7 @@ __license__ = "MIT"
 _logger = logging.getLogger(__name__)
 
 try:
-    import menu
+    from . import menu
 except NotImplementedError:
     _logger.debug("simple_term_menu isn't supported on windows")
 
